@@ -1,5 +1,5 @@
 <?php
-// $Header: /cvsroot/tikiwiki/tiki/lib/trackers/trackerlib.php,v 1.97.2.142 2007/12/10 04:28:34 kerrnel22 Exp $
+// $Header: /cvsroot/tikiwiki/tiki/lib/trackers/trackerlib.php,v 1.97.2.143 2008/04/04 16:49:46 kerrnel22 Exp $
 //this script may only be included - so its better to die if called directly.
 if (strpos($_SERVER["SCRIPT_NAME"],basename(__FILE__)) !== false) {
   header("location: index.php");
@@ -815,7 +815,7 @@ class TrackerLib extends TikiLib {
 					}
 				} else {
 
-					$is_date = (isset($ins_fields["data"][$i]["type"]) and ($ins_fields["data"][$i]["type"] == 'f' or $ins_fields["data"][$i]["type"] == 'j'));
+					$is_date = (isset($ins_fields["data"][$i]["type"]) and ($ins_fields["data"][$i]["type"] == 'f' or $ins_fields["data"][$i]["type"] == 'F' or $ins_fields["data"][$i]["type"] == 'j'));
 					$is_visible = !isset($ins_fields["data"][$i]["isHidden"]) || $ins_fields["data"][$i]["isHidden"] == 'n';
 
 					if ($itemId) {
@@ -1595,6 +1595,10 @@ class TrackerLib extends TikiLib {
 		$type['f'] = array(
 			'label'=>tra('date and time'),
 			'opt'=>false);
+		$type['F'] = array(
+			'label'=>tra('date only'),
+			'opt'=>true,
+			'help'=>tra('Select only a date. If not mandatory, allows blank dates.  Enter a "0" (zero) in the field to the right to default to blank date, otherwise default is today. Flagging mandatory overrides "0" option.') );
 		$type['j'] = array(
 			'label'=>tra('jscalendar'),
 			'opt'=>false);
