@@ -10,7 +10,7 @@
 // hmm. to many session tweaks in setup_smarty ... we need to call this
 require_once('tiki-setup.php');
 
-if ($feature_antibot != 'y') {
+if ($feature_antibot != 'y' && $rnd_num_reg != 'y') {
 	die;
 }
 
